#[repr(transparent)]pub struct Itatbctr1(pub u32);Expand description
The ITATBCTR1 register performs different functions depending on whether the access is a read or a write.
Tuple Fields
0: u32Implementations
Sourceimpl Itatbctr1
impl Itatbctr1
Sourcepub const fn atvalidm0(&self) -> Atvalidm0
pub const fn atvalidm0(&self) -> Atvalidm0
A read returns the value of the atids[n] signals, where the value of the Control Register at 0x000 defines n. A write outputs the value to the atidm port.
Sourcepub const fn set_atvalidm0(&mut self, val: Atvalidm0)
pub const fn set_atvalidm0(&mut self, val: Atvalidm0)
A read returns the value of the atids[n] signals, where the value of the Control Register at 0x000 defines n. A write outputs the value to the atidm port.