#[repr(transparent)]pub struct Itctrl(pub u32);Expand description
The ITCTRL register enables the component to switch from a functional mode, which is the default behavior, to integration mode where the inputs and outputs of the component can be directly controlled for the purposes of integration testing and topology detection.
Tuple Fields
0: u32Implementations